/*
 * Copyright (C) 2004 Felipe Gustavo de Almeida
 * Copyright (C) 2010-2015 The MPDroid Project
 *
 * All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice,this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.anpmech.mpd.connection;

/**
 * This class is a {@link MPDConnectionStatus} which has potential to block the connection.
 */
class BlockingConnectionStatus extends MPDConnectionStatus {

    /**
     * This tracks the connection as blocked or not blocked.
     */
    private volatile boolean mIsBlocked;

    /**
     * The sole constructor.
     *
     * @param listener The connected {@link MPDConnection} instance.
     */
    BlockingConnectionStatus(final MPDConnectionListener listener) {
        super(listener);
    }

    /**
     * This checks if the connection has been marked as blocking.
     *
     * @return True if the connection has been marked as blocking, false otherwise.
     */
    @Override
    boolean isBlocked() {
        return mIsBlocked;
    }

    /**
     * This sets the connection status as blocked.
     */
    @Override
    void setBlocked() {
        debug("Connection blocked");

        mIsBlocked = true;
    }

    /**
     * This sets the connection status as not blocked.
     */
    @Override
    void setNotBlocked() {
        debug("Connection not blocked.");

        mIsBlocked = false;
    }

    @Override
    public String toString() {
        return "BlockingConnectionStatus{" +
                "mIsBlocked=" + mIsBlocked +
                "} " + super.toString();
    }
}
